@@ -128,7 +128,7 @@ class Forum {
 		;
 		
 		if (isset($this->rsp_item_type_id)) {
-			$query .= ", p.profile_create_datetime, p.profile_nic, p.profile_hometown, rsp.rsp_sticky ";
+			$query .= ", p.profile_create_datetime, p.profile_nic, p.profile_hometown, rsp.rsp_sticky, rsp.rsp_featured ";
 		}
 			
 		$query .= "FROM " . $this->db->prefix . "_forum_subject s ";
@@ -162,6 +162,17 @@ class Forum {
 			if (isset($this->rsp_status_id)) {
 				$query .= "rsp.status_id=" . $this->rsp_status_id . " AND ";
 			}
+			
+			if (isset($this->degree_id)) {
+				$query .= "rsp.degree_id>=" . $this->degree_id . " AND ";
+			}
+			else {
+				$query .= "rsp.degree_id IS NULL AND ";
+			}
+			
+			if (isset($this->rsp_featured)) {
+				$query .= "rsp.rsp_featured=" . $this->rsp_featured . " AND ";
+			}
 		}
 
 		if (isset($this->user_id)) {
@@ -207,8 +218,8 @@ class Forum {
 
 		$query .="1=1 ";
 		
-		if (isset($this->order)) {
-			$query .= "order by " . $this->order;
+		if (isset($this->order_by)) {
+			$query .= "order by " . $this->order_by;
 		} else {
 			$query .= "order by s.subject_sticky desc, s.subject_create_datetime desc";
 		}
